# Release notes

## AxsDB 0.1.1 (*upcoming release*)

* Added a converter to the `AbsorptionDatabase._error_handling_config` attribute
  ({ghpr}`12`).
* Added an error_handling_config argument to the
  `AbsorptionDatabase.from_directory()` constructor ({ghpr}`12`).

## AxsDB 0.1.0 (2026-02-17)

* First beta release. AxsDB is now ready for public release.
